import pytest

from program.tests.factories import LinkTypeFactory

pytestmark = pytest.mark.django_db


def url(link_type=None):
    return f"/api/v1/link-types/{link_type.id}/" if link_type else "/api/v1/link-types/"


def test_create_link_type(admin_api_client):
    data = {
        "is_active": True,
        "name": "NAME",
    }

    response = admin_api_client.post(url(), data)

    assert response.status_code == 201

    assert response.data["is_active"] == data["is_active"]
    assert response.data["name"] == data["name"]


def test_retrieve_link_type(common_api_client1, link_type):
    response = common_api_client1.get(url(link_type=link_type))

    assert response.status_code == 200

    assert response.data["is_active"] == link_type.is_active
    assert response.data["name"] == link_type.name


def test_delete_link_type(admin_api_client, link_type):
    response = admin_api_client.delete(url(link_type=link_type))

    assert response.status_code == 204


def test_list_link_types(common_api_client1):
    LINK_TYPES = 3
    LinkTypeFactory.create_batch(size=LINK_TYPES)

    response = common_api_client1.get(url())

    assert response.status_code == 200
    assert len(response.data) == LINK_TYPES


def test_update_is_active(admin_api_client, link_type):
    update = {"is_active": False}

    response = admin_api_client.patch(url(link_type=link_type), update)

    assert response.status_code == 200
    assert response.data["is_active"] == update["is_active"]


def test_update_name(admin_api_client, link_type):
    update = {"name": "NAME"}

    response = admin_api_client.patch(url(link_type=link_type), update)

    assert response.status_code == 200
    assert response.data["name"] == update["name"]
