import pytest

from program.tests.factories import TopicFactory

pytestmark = pytest.mark.django_db


def url(topic=None):
    return f"/api/v1/topics/{topic.id}/" if topic else "/api/v1/topics/"


def test_create_topic(admin_api_client):
    data = {
        "name": "NAME",
        "slug": "topic",
    }

    response = admin_api_client.post(url(), data)

    assert response.status_code == 201

    assert response.data["name"] == data["name"]
    assert response.data["slug"] == data["slug"]


def test_retrieve(common_api_client1, topic):
    response = common_api_client1.get(url(topic=topic))

    assert response.status_code == 200

    assert response.data["name"] == topic.name
    assert response.data["slug"] == topic.slug


def test_delete(admin_api_client, topic):
    response = admin_api_client.delete(url(topic=topic))

    assert response.status_code == 204


def test_list(common_api_client1):
    TOPICS = 3
    TopicFactory.create_batch(size=TOPICS)

    response = common_api_client1.get(url())

    assert response.status_code == 200
    assert len(response.data) == TOPICS


def test_update_is_active(admin_api_client, topic):
    update = {"is_active": False}

    response = admin_api_client.patch(url(topic=topic), update)

    assert response.status_code == 200
    assert response.data["is_active"] is update["is_active"]


def test_update_name(admin_api_client, topic):
    update = {"name": "NAME"}

    response = admin_api_client.patch(url(topic=topic), update)

    assert response.status_code == 200
    assert response.data["name"] == update["name"]


def test_update_slug(admin_api_client, topic):
    update = {"slug": "topic"}

    response = admin_api_client.patch(url(topic=topic), update)

    assert response.status_code == 200
    assert response.data["slug"] == update["slug"]
